﻿<#	
	===========================================================================
	 Created on:   	1/11/2019 10:28
	 Created by:   	jisodl0
	 Organization: 	J.B. Hunt
	 Filename:     	Restart-JBService.ps1
	-------------------------------------------------------------------------
	 Module Name: Artemis
	===========================================================================
#>

<#
	.SYNOPSIS
		Restart a service used by J.B. Hunt.

	.DESCRIPTION
		Restarts the given service on the given computer so long as you have the
  necessary permissions. This is done by retrieving the service from the given
  computer name, stopping that service, then starting it back up. Each step
  requires confirmation before continuing to the next to avoid any issues.

	.PARAMETER ServiceName
		A description of the ServiceName parameter.

	.PARAMETER ComputerName
		The name of the computer/server to restart the given service on. Defaults to
	the local machine if no value is provided.

	.EXAMPLE
		PS C:\> Restart-JBService -ServiceName 'tomcat*'

	.EXAMPLE
		PS C:\> Restart-JBService tomcat* JVPWEB10101

	.EXAMPLE
		PS C:\> Restart-JBService 'Razer Chroma*' 'JVPWEB10101'
#>
function Restart-JBService {
	[CmdletBinding(PositionalBinding = $true)]
	param (
		[Parameter(Mandatory = $true,
							 Position = 0)]
		[Alias('Name', 'Service')]
		[System.String]
		$ServiceName,

		[Parameter(Position = 1,
							 HelpMessage = 'Which computer would you like to reset the service on?')]
		[Alias('Computer', 'ServerName', 'Server')]
		[System.String]
		$ComputerName = $env:COMPUTERNAME
	)

	# Pull all services with the service name and on the given computer.
	$Service = Get-Service -Name $ServiceName -ComputerName $ComputerName

	# If more than one service was found, get the one the user wants to restart.
	if ($Service.Length -gt 1) {
		$Services = @()

		for ($x = 0; $x -lt $Service.Length; $x++) {
			[hashtable]$Data = @{}

			$Data.Add('Index', $x)
			$Data.Add('Status', $Service[$x].Status)
			$Data.Add('Name', $Service[$x].Name)

			$DataTable = New-Object -TypeName System.Management.Automation.PSObject -Property $Data
			$Services += $DataTable
		}

		# Write out the headers for the services.
		Write-Host "`nIndex  Status Name"
		Write-Host '-----  -----  ----'

		# Write the table of services to the console.
		$Services | ForEach-Object { Write-ServiceOut $_ }

		# Get the index of the correct service to restart.
		$Index = Read-Host "`nWhich service would you like to restart? (0 - $x)"

		# Set the Service variable to the correct service.
		$Service = $Service[$Index]
	}

	# Write out the headers for the service.
	Write-Host "`nIndex  Status Name"
	Write-Host '-----  -----  ----'

	# Write the selected service to the console for verification.
	Write-ServiceOut $Service

	# Verify this is the correct service.
	$CorrectService = Read-Host -Prompt "`nIs this the correct service? (Y/N)"

	# Make sure the user response is lowercase.
	if ($CorrectService.Length -gt 0) { $CorrectService = $CorrectService.ToLower() }

	if ($CorrectService.StartsWith('y') -or ($CorrectService.Length -eq 0)) {
		# Stop the requested service.
		Stop-Service $Service

		# Verify the user wishes to continue with the "restart".
		$ContFlag = Read-Host -Prompt 'Continue with restart? (Y/N)'

		# Make sure the user response is lowercase.
		if ($ContFlag.Length -gt 0) { $ContFlag = $ContFlag.ToLower() }

		if ($ContFlag.StartsWith('y') -or ($ContFlag.Length -eq 0)) {
			Start-Service $Service
		}
	}
}
	
function Write-ServiceOut {
	param (
		[Parameter(Mandatory = $true,
		           Position = 0)]
		$Service
	)

	# Write the index number to the console.
	Write-Host "    $($Service.Index)" -ForegroundColor Yellow -NoNewline

	# Write the status to the console.
	if ($Service.Status -eq 'Running') {
		# If the service is running, output the text as green.
		Write-Host " $($Service.Status) " -ForegroundColor Green -NoNewline
	} elseif ($Service.Status -eq 'Stopped') {
		# If the service is stopped, output the text as red.
		Write-Host " $($Service.Status) " -ForegroundColor Red -NoNewline
	}

	Write-Host $Service.Name
}
